@@ -6,7 +6,7 @@ use Carp ();
 use JSON::MaybeXS ();
 use constant DEBUG => $ENV{TELEGRAM_BOTAPI_DEBUG} || 0;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 my $json; # for debugging purposes, only defined when DEBUG = 1
 
 BEGIN {
@@ -205,12 +205,16 @@ sub api_request
 sub parse_error
 {
     my $r = { type => "unknown", msg => $_[1] || $@ };
-    return $r unless $r->{msg} =~ /ERROR: (?:code (?<code>[0-9]+): )?(?<msg>.+?)(?:\s*at .+)?$/m;
+    # The following regexp matches the error code to the first group and the error message to the
+    # second.
+    return $r unless $r->{msg} =~ /ERROR: (?:code ([0-9]+): )?(.+?)(?:\s*at .+)?$/m;
+    # Find and save the error code and message.
+    $r->{code} = $1 if $1;
+    $r->{msg}  = $2;
     # If the error message has a code, then it comes from the BotAPI. Otherwise, it's our agent
     # telling us something went wrong.
-    $r->{type} = exists $+{code} ? "api" : "agent" if $+{msg} ne "something went wrong!";
-    # Join our response with the matched groups, then return.
-    +{ %$r, %+ }
+    $r->{type} = exists $r->{code} ? "api" : "agent" if $r->{msg} ne "something went wrong!";
+    $r
 }
 
 sub agent
@@ -231,6 +235,8 @@ sub _fix_request_args
     if (@$args > 1 and $args->[1] eq "DBG")
     {
         my (undef, $data) = splice @$args, 1, 2;
+        # Be sure to get rid of the `DBG` key in our copy too.
+        splice @$args_cpy, 1, 2;
         # In the debug output, substitute the JSON-encoded data (which is not human readable) with
         # the raw POST arguments.
         $args_cpy->[2] = $data;
